pub fn spawn_txsender_loop(config: TxSenderConfig) -> JoinHandle<()>Expand description
Spawns a tokio task that runs txsender indefinitely.
This is a standalone loop helper with no dependency on the clementine-core task framework.
Callers that own the txsender schema should run migrations before spawning it.